@@ -2,9 +2,9 @@
  * (c)LGPL2+
  *
  * LXQt - The Lightweight Desktop Environment
- * https://lxqt.org
+ * https://lxqt-project.org
  *
- * Copyright: 2010-2011 Razor team
+ * Copyright: 2011-12 Razor Team;  2012-2020 LXQt Project
  * Authors:
  *   Petr Vanek <petr@scribus.info>
  *
@@ -71,7 +71,7 @@ AboutDialogPrivate::AboutDialogPrivate()
     techBrowser->setHtml(info.html());
     techBrowser->viewport()->setAutoFillBackground(false);
 
-    connect(techCopyToClipboardButton, SIGNAL(clicked()), this, SLOT(copyToCliboardTechInfo()));
+    connect(techCopyToClipboardButton, &QPushButton::clicked, this, &AboutDialogPrivate::copyToCliboardTechInfo);
     this->setAttribute(Qt::WA_DeleteOnClose);
     show();
 
